@@ -32,4 +32,10 @@
 #'   geom_boxplot(aes(gear, disp, group = gear))
 #'
 #' @keywords internal
-'_PACKAGE'
+"_PACKAGE"
+
+## usethis namespace: start
+#' @import rlang
+#' @import cli
+## usethis namespace: end
+NULL
